@@ -261,4 +261,8 @@ sio_module_t sio_module_sa = {
     NULL
 };
 
+#else
+
+const char __sio_sa_c[] = "";
+
 #endif /* ENABLE_SA */
